# uxu

[![PyPI - Version](https://img.shields.io/pypi/v/uxu.svg)](https://pypi.org/project/uxu)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/uxu.svg)](https://pypi.org/project/uxu)

Make little user interfaces without fussing around with JavaScript.

This library is very WIP.

## Installation

```console
pip install uxu
```

## License

`uxu` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
